#
# Conditional build:
%bcond_without	lash		# LASH support (GPL)
%bcond_with	midishare	# MidiShare support
%bcond_without	pipewire	# pipewire support
%bcond_without	portaudio	# portaudio support
%bcond_without	readline	# readline line editing (GPL)
%bcond_without	systemd		# systemd notify support
#
Summary:	FluidSynth - a software, real-time synthesizer
Summary(pl.UTF-8):	FluidSynth - programowy syntezator działający w czasie rzeczywistym
Name:		fluidsynth
Version:	2.3.4
Release:	1
%if %{with lash} || %{with readline}
License:	GPL v2+ (enforced by lash/readline), LGPL v2+ (fluidsynth itself)
%else
License:	LGPL v2+
%endif
Group:		Applications/Sound
#Source0Download: https://github.com/FluidSynth/fluidsynth/releases
Source0:	https://github.com/FluidSynth/fluidsynth/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	9e6f11b3a0b9981273e4d1fdadcd9533
URL:		https://www.fluidsynth.org/
BuildRequires:	SDL2-devel >= 2
BuildRequires:	alsa-lib-devel >= 0.9.1
BuildRequires:	cmake >= 3.13
BuildRequires:	dbus-devel >= 1.0.0
BuildRequires:	gettext-tools
BuildRequires:	glib2-devel >= 1:2.26.0
BuildRequires:	jack-audio-connection-kit-devel
BuildRequires:	ladspa-devel
%{?with_lash:BuildRequires:	lash-devel >= 0.3}
# OpenMP 4.0
BuildRequires:	libgomp-devel >= 6:4.9
BuildRequires:	libinstpatch-devel >= 1.1.0
BuildRequires:	libsndfile-devel >= 1.0.18
%{?with_midishare:BuildRequires:	midishare-devel}
BuildRequires:	pkgconfig
%{?with_pipewire:BuildRequires:	pipewire-devel >= 0.3}
%{?with_portaudio:BuildRequires:	portaudio-devel >= 19}
BuildRequires:	pulseaudio-devel >= 0.9.8
%{?with_readline:BuildRequires:	readline-devel}
BuildRequires:	rpmbuild(macros) >= 1.213
%{?with_systemd:BuildRequires:	systemd-devel >= 1:209}
Requires:	alsa-lib >= 0.9.1
Requires:	glib2 >= 1:2.26.0
Requires:	libsndfile >= 1.0.18
Suggests:	soundfont-fluid
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Fluid Synth is a software, real-time synthesizer based on the
Soundfont 2 specifications.

%description -l pl.UTF-8
Fluid Synth to programowy, działający w czasie rzeczywistym syntezator
oparty na specyfikacji Soundfont 2.

%package devel
Summary:	Development files for the FluidSynth
Summary(pl.UTF-8):	Pliki nagłówkowe dla FluidSynth
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	alsa-lib-devel >= 0.9.1
Requires:	dbus-devel >= 1.0.0
Requires:	glib2-devel >= 1:2.26.0
Requires:	jack-audio-connection-kit-devel
%{?with_lash:Requires:	lash-devel >= 0.3}
Requires:	libsndfile-devel >= 1.0.18
%{?with_midishare:Requires: midishare-devel}
%{?with_pipewire:Requires:	pipewire-devel >= 0.3}
%{?with_portaudio:Requires:	portaudio-devel >= 19}
Requires:	pulseaudio-devel >= 0.9.8
%{?with_readline:Requires: readline-devel}
Obsoletes:	fluidsynth-static < 2

%description devel
This package contains the header files necessary to develop
applications using FluidSynth.

%description devel -l pl.UTF-8
Pakiet ten zawiera pliki nagłówkowe potrzebne do tworzenia i
kompilacji aplikacji korzystających z bibliotek FluidSynth.

%prep
%setup -q

%build
%cmake -B build \
	-Denable-midishare=%{with midishare} \
	-Denable-lash=%{with lash} \
	%{!?with_pipewire:-Denable-pipewire=OFF} \
	-Denable-portaudio=%{with portaudio} \
	-Denable-readline=%{with readline} \
	%{!?with_systemd:-Denable-systemd=OFF}

%{__make} -C build

%install
rm -rf $RPM_BUILD_ROOT

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS README.md THANKS TODO
%attr(755,root,root) %{_bindir}/fluidsynth
%attr(755,root,root) %{_libdir}/libfluidsynth.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libfluidsynth.so.3
%{_mandir}/man1/fluidsynth.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libfluidsynth.so
%{_includedir}/fluidsynth.h
%{_includedir}/fluidsynth
%{_pkgconfigdir}/fluidsynth.pc
%{_libdir}/cmake/fluidsynth
%changelog
* Sat Oct 21 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/fluidsynth.git;a=log;h=master

* Sat Oct 21 2023 Jakub Bogusz <qboosh@pld-linux.org> 43584f0
- updated to 2.3.4

* Thu Mar 30 2023 Jakub Bogusz <qboosh@pld-linux.org> f3eb153
- updated to 2.3.1 (introduces pipewire driver)

* Thu Mar 30 2023 Jakub Bogusz <qboosh@pld-linux.org> b5e44da
- updated to 2.2.9 (the last 2.2.x release)

* Thu Mar 31 2022 Jakub Bogusz <qboosh@pld-linux.org> 8a24b08
- updated to 2.2.6

* Fri Mar 18 2022 Jakub Bogusz <qboosh@pld-linux.org> 69bd0c4
- updated to 2.2.5

* Wed Jan 05 2022 Jakub Bogusz <qboosh@pld-linux.org> e2696d3
- updated to 2.2.4 (new soname)

* Tue Dec 21 2021 Jakub Bogusz <qboosh@pld-linux.org> e71a1b9
- updated URL, fixed libinstpatch BR

* Tue Dec 21 2021 Jakub Bogusz <qboosh@pld-linux.org> ac3050b
- updated to 2.1.9

* Mon Sep 27 2021 Jakub Bogusz <qboosh@pld-linux.org> 08a54b0
- fixed fluidsynth-static Obsoletes

* Thu Apr 29 2021 Jakub Bogusz <qboosh@pld-linux.org> e41dc2e
- updated to 2.1.7

* Sun Jan 17 2021 Jakub Bogusz <qboosh@pld-linux.org> 81d6286
- nothing to do with oboe on Linux, it's Android specific

* Sun Jan 17 2021 Jakub Bogusz <qboosh@pld-linux.org> f6e767e
- updated to 2.1.6

* Sat Dec 05 2020 Jan Palus <atler@pld-linux.org> c18887e
- don't require portaudio-devel when building without portaudio

* Mon Mar 16 2020 Jakub Bogusz <qboosh@pld-linux.org> c26a125
- updated to 2.1.1

* Thu Oct 17 2019 Arkadiusz Miśkiewicz <arekm@maven.pl> 6028d2e
- release 2 (by relup.sh)

* Fri Aug 30 2019 Marcin Krol <hawk@tld-linux.org> 0672ba8
- updated to 2.0.6

* Sat Apr 20 2019 Jakub Bogusz <qboosh@pld-linux.org> ef862a8
- updated to 2.0.5

* Wed Apr 10 2019 Jakub Bogusz <qboosh@pld-linux.org> e2b99d1
- updated to 2.0.4, obsolete dropped -static package

* Mon Nov 19 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> 2566f65
- Version: 2.0.2 (soname change)

* Sun Dec 17 2017 Jakub Bogusz <qboosh@pld-linux.org> c2d1ce4
- updated to 1.1.8
- added soname patch (fix broken lt versioning)

